// NewFileFormatDlg.h
// (c) 2003 exeal

#ifndef _NEW_FILE_FORMAT_DLG_H_
#define _NEW_FILE_FORMAT_DLG_H_
#include "..\Manah\Dialog.h"
#include "Ascension\EditDoc.h"	// BreakType
using Manah::Windows::Controls::CDialog;


namespace Alpha {

// CNewFileFormatDlg class definition
/////////////////////////////////////////////////////////////////////////////

///	uw肵ĐVKv_CAO
class CNewFileFormatDlg : public CDialog {
	// f[^o
public:
	Manah::Text::CodePage	m_nCodePage;			// R[hy[W
	Ascension::BreakType	m_breakType;			// sR[h
	list<wstring>			m_listDocumentTypes;	// ^CṽXg
	size_t					m_iDocumentType;		// Iꂽ^Cv

	// bZ[Wnh
protected:
	bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);
	void	OnOK();
};

} /* namespace Alpha */

#endif /* _NEW_FILE_FORMAT_DLG_H_ */

/* [EOF] */